==> 0.2.8.tar.gz: lib/pages/home/ota/BleOta.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/handle/AutoErrorHandle.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Ota.dart';

///蓝牙ota

class BleOtaWidget extends StatefulWidget {
  final String deviceId;

  const BleOtaWidget({Key? key, required this.deviceId}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _BleOtaState();
  }
}

class _BleOtaState extends State<BleOtaWidget> {
  String deviceName = "";
  bool isNewVersion = false; //是否有新版本
  String version = "";
  bool isUpgrading = false; //是否正在升级
  double progress = 0; //当前进度
  @override
  void initState() {
    super.initState();
    _getVersionInfo();
  }

  /// 获得当前设备版本信息
  _getVersionInfo() {
    DeviceManage().device(widget.deviceId).then((value) {
      setState(() {
        version = value!["device"]["version"];
        deviceName = value["deviceName"];
      });
      _checkVersion();
    });
  }

  ///检测是否有新版本
  _checkVersion() async {
    try {
      var info = await Ota().checkUpVersion(widget.deviceId);
      if (info["newVersion"] != null) {
        version = info["newVersion"].toRadixString(16);
      }
      setState(() {
        isNewVersion = info["isNewVersion"];
      });
      if (isNewVersion) {
        EasyLoading.showToast(S.current.device_discoverNewVersion);
      }
    } on PlatformException catch (e) {
      debugPrint("异常${e.message}");
      var auto = AutoErrorHandle.auto(e);
      EasyLoading.showToast(auto.error);
    }
  }

  ///点击升级按钮
  _upgrade() {
    isUpgrading = true;
    EasyLoading.show(status: S.current.device_loading);

    Ota()
        .startBleOta(
            deviceId: widget.deviceId,
            progress: (double value) {
              if (progress == 0) EasyLoading.dismiss();
              if (mounted) {
                setState(() {
                  progress = value;
                });
              }
            })
        .then((value) {
      EasyLoading.dismiss();
      isUpgrading = false;
      isNewVersion = false;
      progress = 0;
      if (mounted) {
        setState(() {});
      }
      EasyLoading.showToast(S.current.device_success);
    }).onError((error, stackTrace) {
      progress = 0;
      EasyLoading.dismiss();
      isUpgrading = false;
      setState(() {});
      final e = error as PlatformException;
      EasyLoading.showToast(AutoErrorHandle.auto(e).error,
          duration: const Duration(seconds: 4));
    });
  }

  @override
  void dispose() {
    Ota().stopBleOta(widget.deviceId);
    super.dispose();
    EasyLoading.dismiss();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        title: Text(S.of(context).device_ota + "($deviceName)"),
      ),
      body: Container(
        alignment: Alignment.center,
        padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
        child: AnimatedSwitcher(
            duration: const Duration(milliseconds: 200),
            transitionBuilder: (Widget child, Animation<double> animation) {
              return ScaleTransition(
                  child: child, scale: animation); //进行自定义的切换动画
            },
            child: isUpgrading
                ? Row(
                    children: [
                      const Icon(
                        WitsIcon.shoujihao,
                        color: Colors.white,
                        size: 50,
                      ),
                      Expanded(
                        flex: 1,
                        child: Column(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Text("${(progress * 100).toStringAsFixed(2)}%",
                                style: const TextStyle(color: Colors.white)),
                            Slider(
                              value: progress,
                              thumbColor: Colors.white,
                              activeColor: Theme.of(context).primaryColorLight,
                              inactiveColor: Colors.white,
                              onChanged: (v) {},
                              max: 1,
                            )
                          ],
                        ),
                      ),
                      const Icon(
                        WitsIcon.shebei,
                        color: Colors.white,
                        size: 50,
                      ),
                    ],
                  )
                : Column(
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    children: [
                      const SizedBox(),
                      Column(mainAxisSize: MainAxisSize.min, children: [
                        const Icon(WitsIcon.gujianshengji,
                            size: 100, color: Colors.white),
                        Text(
                            isNewVersion
                                ? S.of(context).device_discoverNewVersion
                                : S.of(context).device_latestVersion,
                            style: const TextStyle(color: Colors.white)),
                        Text(
                            S.of(context).device_deviceVersionNumber +
                                " $version",
                            style: const TextStyle(color: Colors.white))
                      ]),
                      isNewVersion
                          ? MaterialButton(
                              color: Theme.of(context).primaryColorLight,
                              padding:
                                  const EdgeInsets.fromLTRB(60, 20, 60, 20),
                              onPressed: _upgrade,
                              child: Text(S.of(context).device_OneKeyUpgrade,
                                  style: const TextStyle(
                                      color: Colors.white, fontSize: 18)),
                            )
                          : const SizedBox()
                    ],
                  )),
      ),
    );
  }
}

==> 0.3.1.tar.gz: lib/pages/home/ota/BleOta.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/handle/AutoErrorHandle.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Ota.dart';

///蓝牙ota

class BleOtaWidget extends StatefulWidget {
  final String deviceId;

  const BleOtaWidget({Key? key, required this.deviceId}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _BleOtaState();
  }
}

class _BleOtaState extends State<BleOtaWidget> {
  String deviceName = "";
  bool isNewVersion = false; //是否有新版本
  String version = "";
  bool isUpgrading = false; //是否正在升级
  double progress = 0; //当前进度
  @override
  void initState() {
    super.initState();
    _getVersionInfo();
  }

  /// 获得当前设备版本信息
  _getVersionInfo() {
    DeviceManage().device(widget.deviceId).then((value) {
      setState(() {
        version = value!["device"]["version"];
        deviceName = value["deviceName"];
      });
      _checkVersion();
    });
  }

  ///检测是否有新版本
  _checkVersion() async {
    try {
      var info = await Ota().checkUpVersion(widget.deviceId);
      if (info["newVersion"] != null) {
        version = info["newVersion"].toRadixString(16);
      }
      setState(() {
        isNewVersion = info["isNewVersion"];
      });
      if (isNewVersion) {
        EasyLoading.showToast(S.current.device_discoverNewVersion);
      }
    } on PlatformException catch (e) {
      debugPrint("异常${e.message}");
      var auto = AutoErrorHandle.auto(e);
      EasyLoading.showToast(auto.error,duration: const Duration(milliseconds: 4000));
    }
  }

  ///点击升级按钮
  _upgrade() {
    isUpgrading = true;
    EasyLoading.show(status: S.current.device_loading);

    Ota()
        .startBleOta(
            deviceId: widget.deviceId,
            progress: (double value) {
              if (progress == 0) EasyLoading.dismiss();
              if (mounted) {
                setState(() {
                  progress = value;
                });
              }
            })
        .then((value) {
      EasyLoading.dismiss();
      isUpgrading = false;
      isNewVersion = false;
      progress = 0;
      if (mounted) {
        setState(() {});
      }
      EasyLoading.showToast(S.current.device_success);
    }).onError((error, stackTrace) {
      progress = 0;
      EasyLoading.dismiss();
      isUpgrading = false;
      setState(() {});
      final e = error as PlatformException;
      EasyLoading.showToast(AutoErrorHandle.auto(e).error,
          duration: const Duration(seconds: 4));
    });
  }

  @override
  void dispose() {
    Ota().stopBleOta(widget.deviceId);
    super.dispose();
    EasyLoading.dismiss();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        title: Text(S.of(context).device_ota + "($deviceName)"),
      ),
      body: Container(
        alignment: Alignment.center,
        padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
        child: AnimatedSwitcher(
            duration: const Duration(milliseconds: 200),
            transitionBuilder: (Widget child, Animation<double> animation) {
              return ScaleTransition(
                  child: child, scale: animation); //进行自定义的切换动画
            },
            child: isUpgrading
                ? Row(
                    children: [
                      const Icon(
                        WitsIcon.shoujihao,
                        color: Colors.white,
                        size: 50,
                      ),
                      Expanded(
                        flex: 1,
                        child: Column(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Text("${(progress * 100).toStringAsFixed(2)}%",
                                style: const TextStyle(color: Colors.white)),
                            Slider(
                              value: progress,
                              thumbColor: Colors.white,
                              activeColor: Theme.of(context).primaryColorLight,
                              inactiveColor: Colors.white,
                              onChanged: (v) {},
                              max: 1,
                            )
                          ],
                        ),
                      ),
                      const Icon(
                        WitsIcon.shebei,
                        color: Colors.white,
                        size: 50,
                      ),
                    ],
                  )
                : Column(
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    children: [
                      const SizedBox(),
                      Column(mainAxisSize: MainAxisSize.min, children: [
                        const Icon(WitsIcon.gujianshengji,
                            size: 100, color: Colors.white),
                        Text(
                            isNewVersion
                                ? S.of(context).device_discoverNewVersion
                                : S.of(context).device_latestVersion,
                            style: const TextStyle(color: Colors.white)),
                        Text(
                            S.of(context).device_deviceVersionNumber +
                                " $version",
                            style: const TextStyle(color: Colors.white))
                      ]),
                      isNewVersion
                          ? MaterialButton(
                              color: Theme.of(context).primaryColorLight,
                              padding:
                                  const EdgeInsets.fromLTRB(60, 20, 60, 20),
                              onPressed: _upgrade,
                              child: Text(S.of(context).device_OneKeyUpgrade,
                                  style: const TextStyle(
                                      color: Colors.white, fontSize: 18)),
                            )
                          : const SizedBox()
                    ],
                  )),
      ),
    );
  }
}
